from dataclasses import dataclass, field
from typing import Dict, List, Optional
from uuid import UUID, uuid4
from .[[ entity_name.lower() ]]_exceptions import *
from .[[ entity_name.lower() ]]_schemas import *